@@ -51,13 +51,8 @@
 
 #include <openvas/base/openvas_file.h>
 #include <openvas/base/settings.h>
-#ifdef LIBOPENVAS_OLD_INCLUDE_PATH
-#include <openvas/openvas_auth.h>
-#include <openvas/openvas_uuid.h>
-#else
 #include <openvas/misc/openvas_auth.h>
 #include <openvas/misc/openvas_uuid.h>
-#endif
 
 #ifdef S_SPLINT_S
 #include "splint.h"
@@ -342,6 +337,23 @@ print_users_text (GSList * users)
   return response;
 }
 
+/**
+ *
+ * @brief Validates a username.
+ *
+ * @param[in]  name  The name.
+ *
+ * @return 0 if the username is valid, 1 if not.
+ */
+int
+validate_username (const gchar * name)
+{
+  if (g_regex_match_simple ("^[[:alnum:]-_]+$", name, 0, 0))
+    return 0;
+  else
+    return 1;
+}
+
 /**
  * @brief Adds a new user to the OpenVAS installation.
  *
@@ -368,6 +380,12 @@ openvas_admin_add_user (const gchar * name, const gchar * password,
   assert (role != NULL);
   assert (directory != NULL);
 
+  if (validate_username (name) != 0)
+    {
+      g_warning ("Invalid characters in user name!");
+      return -1;
+    }
+
   if (strcmp (name, "om") == 0)
     {
       g_warning ("Attempt to add special \"om\" user!");
@@ -1368,7 +1386,7 @@ openvas_current_sync (const gchar * sync_script, gchar ** timestamp,
  */
 int
 openvas_admin_modify_settings (const char *config_file, const char *group,
-                               const array_t * new_settings /* setting_t */ )
+                               const array_t * new_settings /* admin_setting_t */ )
 {
   if (new_settings)
     {
@@ -1513,7 +1531,7 @@ openvas_admin_schema (gchar *format, gchar **output_return, gsize *output_length
     else
       return 1;
 
-    script_dir = g_build_filename (OPENVAS_SYSCONF_DIR,
+    script_dir = g_build_filename (OPENVAS_DATA_DIR,
                                    "openvasad",
                                    "global_schema_formats",
                                    uuid_format,
@@ -1570,7 +1588,7 @@ openvas_admin_schema (gchar *format, gchar **output_return, gsize *output_length
 
       /* Call the script. */
 
-      command = g_strdup_printf ("/bin/sh %s " OPENVAS_SYSCONF_DIR
+      command = g_strdup_printf ("/bin/sh %s " OPENVAS_DATA_DIR
                                  "/openvasad/global_schema_formats"
                                  "/af659394-181e-11e0-8cd5-002264764cea/OAP.xml"
                                  " > %s"
