@@ -95,13 +95,8 @@
 #include <openvas/base/openvas_file.h>  /* for openvas_file_read_b64_encode */
 #include <openvas/base/openvas_string.h>        /* for openvas_append_text */
 #include <openvas/base/settings.h>
-#ifdef LIBOPENVAS_OLD_INCLUDE_PATH
-#include <openvas/openvas_auth.h>
-#include <openvas/openvas_logging.h>
-#else
 #include <openvas/misc/openvas_auth.h>
 #include <openvas/misc/openvas_logging.h>
-#endif
 
 #ifdef S_SPLINT_S
 #include "splint.h"
@@ -2279,6 +2274,7 @@ oap_xml_handle_text ( /*@unused@ */ GMarkupParseContext * context,
     case CLIENT_MODIFY_SETTINGS_SETTING_VALUE:
       openvas_append_text (&modify_settings_data->setting_value, text,
                            text_len);
+      break;
 
     case CLIENT_MODIFY_USER_HOSTS:
       openvas_append_text (&modify_user_data->hosts, text, text_len);
