@@ -51,11 +51,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#ifdef LIBOPENVAS_OLD_INCLUDE_PATH
-#include <openvas/openvas_server.h>
-#else
 #include <openvas/misc/openvas_server.h>
-#endif
 
 #ifdef S_SPLINT_S
 /* FIX Weird that these are missing. */
