@@ -38,6 +38,7 @@
  * @file  openvasad.c
  * @brief The OpenVAS Administrator
  */
+#define _GNU_SOURCE
 
 #include "admin.h"
 #include "oapd.h"
@@ -65,16 +66,11 @@
 #include <signal.h>
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <termios.h>  /* for tcsetattr */
 
-#ifdef LIBOPENVAS_OLD_INCLUDE_PATH
-#include <openvas_logging.h>
-#include <openvas_server.h>
-#include <openvas_auth.h>
-#else
 #include <openvas/misc/openvas_logging.h>
 #include <openvas/misc/openvas_server.h>
 #include <openvas/misc/openvas_auth.h>
-#endif
 #include <openvas/base/pidfile.h>
 #include <openvas/base/settings.h>
 
@@ -400,6 +396,45 @@ handle_sigint (int signal)
 {
   exit (EXIT_SUCCESS);
 }
+
+/**
+ * @brief Reads an entire line from a stream, suppressing character output.
+ *
+ * @param[out]  lineptr  Location of the buffer where the line is stored.
+ * @param[out]  n  Size of allocated buffer in lineptr is not null.
+ * @param[in] stream  Stream from which the line should be read.
+ *
+ * This function mimics the behaviour of getline (). Please see the man page of
+ * getline () for additional information about the parameters. This function was
+ * taken from the example provided in the GNU C Library, for example at
+ * http://www.gnu.org/s/libc/manual/html_node/getpass.html.
+ *
+ * @todo Move this function to openvas-libraries since openvas-cli uses it as
+ * well.
+ */
+ssize_t
+read_password (char **lineptr, size_t *n, FILE *stream)
+{
+  struct termios old, new;
+  int nread;
+
+  /* Turn echoing off and fail if we can't. */
+  if (tcgetattr (fileno (stream), &old) != 0)
+    return -1;
+  new = old;
+  new.c_lflag &= ~ECHO;
+  if (tcsetattr (fileno (stream), TCSAFLUSH, &new) != 0)
+    return -1;
+
+  /* Read the password. */
+  nread = getline (lineptr, n, stream);
+
+  /* Restore terminal. */
+  (void) tcsetattr (fileno (stream), TCSAFLUSH, &old);
+
+  return nread;
+}
+
 
 
 /* Main. */
@@ -459,7 +494,10 @@ main (int argc, char **argv)
      "Use port number <number>.", "<number>"},
     {"command", 'c', 0, G_OPTION_ARG_STRING, &command,
      "OAP command (e.g. add_user, remove_user, list_users)", "<command>"},
-    {"name", 'n', 0, G_OPTION_ARG_STRING, &name,
+    /** @deprecated Hidden option for backwards compatibility */
+    {"name", 'n', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING, &name,
+     "Username when creating, editing or removing a user", "<name>"},
+    {"username", 'u', 0, G_OPTION_ARG_STRING, &name,
      "Username when creating, editing or removing a user", "<name>"},
     {"password", 'w', 0, G_OPTION_ARG_STRING, &password,
      "Password for the new user", "<password>"},
@@ -682,23 +720,23 @@ main (int argc, char **argv)
       /* Log everything to stdout and stderr. */
       g_log_set_default_handler ((GLogFunc) openvas_log_func, NULL);
 
-      tracef ("   OpenVAS Administrator\n");
+      infof ("   OpenVAS Administrator\n");
 
       if (users_dir == NULL)
         {
-          tracef ("   users_dir not set, setting to default\n");
+          infof ("   users_dir not set, setting to default\n");
           users_dir = OPENVAS_USERS_DIR;
         }
 
-      tracef ("   Using directory %s as the users directory\n", users_dir);
+      infof ("   Using directory %s as the users directory\n", users_dir);
 
       if (scanner_config_file == NULL)
         {
-          tracef ("   scanner_config_file not set, setting to default\n");
+          infof ("   scanner_config_file not set, setting to default\n");
           scanner_config_file = OPENVAS_CONFIG_FILE;
         }
 
-      tracef ("   Using %s as the scanner config file\n", scanner_config_file);
+      infof ("   Using %s as the scanner config file\n", scanner_config_file);
 
       /* account overrides name and password.  If an account is specified, the
        * username and password are extracted and copied into name and password
@@ -735,13 +773,41 @@ main (int argc, char **argv)
         {
           gchar *rules;
 
-          if (name == NULL || password == NULL)
+          if (name == NULL)
             {
-              g_warning ("You need to provide both a username and a password to"
+              g_warning ("You need to provide a username to"
                          " create a new user.");
               exit (EXIT_FAILURE);
             }
 
+          if (password == NULL)
+            {
+              gchar *pw = NULL;
+              size_t n;
+
+              printf ("Enter password: ");
+              int ret = read_password (&pw, &n, stdin);
+              printf ("\n");
+
+              if (ret < 0)
+                {
+                  g_warning ("Failed to read password from console!");
+                  exit (EXIT_FAILURE);
+                }
+
+              /* Remove the trailing newline character. */
+              pw[ret - 1] = '\0';
+
+              if (strlen (pw) > 0)
+                password = pw;
+              else
+                {
+                  g_warning ("You need to provide a password to"
+                             " create a new user.");
+                  exit (EXIT_FAILURE);
+                }
+            }
+
           if (rules_file == NULL)
             {
               rules = NULL;
@@ -1035,31 +1101,31 @@ main (int argc, char **argv)
   g_free (rc_name);
   setup_log_handlers (log_config);
 
-  tracef ("   OpenVAS Administrator\n");
+  infof ("   OpenVAS Administrator\n");
 
   if (users_dir == NULL)
     {
-      tracef ("   users_dir not set, setting to default\n");
+      infof ("   users_dir not set, setting to default\n");
       users_dir = OPENVAS_USERS_DIR;
     }
 
-  tracef ("   Using directory %s as the users directory\n", users_dir);
+  infof ("   Using directory %s as the users directory\n", users_dir);
 
   if (sync_script == NULL)
     {
-      tracef ("   sync_script not set, setting to default\n");
+      infof ("   sync_script not set, setting to default\n");
       sync_script = OPENVAS_SYNC_SCRIPT_DIR "/openvas-nvt-sync";
     }
 
-  tracef ("   Using %s as the synchronization script\n", sync_script);
+  infof ("   Using %s as the synchronization script\n", sync_script);
 
   if (scanner_config_file == NULL)
     {
-      tracef ("   scanner_config_file not set, setting to default\n");
+      infof ("   scanner_config_file not set, setting to default\n");
       scanner_config_file = OPENVAS_CONFIG_FILE;
     }
 
-  tracef ("   Using %s as the scanner config file\n", scanner_config_file);
+  infof ("   Using %s as the scanner config file\n", scanner_config_file);
 
   if (administrator_port_string)
     {
@@ -1242,9 +1308,9 @@ main (int argc, char **argv)
       exit (EXIT_FAILURE);
     }
 
-  tracef ("   Administrator bound to address %s port %i\n",
-          administrator_address_string ? administrator_address_string : "*",
-          ntohs (administrator_address.sin_port));
+  infof ("   Administrator bound to address %s port %i\n",
+         administrator_address_string ? administrator_address_string : "*",
+         ntohs (administrator_address.sin_port));
 
   /* Enable connections to the socket. */
 
