@@ -32,11 +32,7 @@
 
 /* @todo Only include these in tests that use them. */
 #include <openvas/omp/omp.h>
-#ifdef LIBOPENVAS_OLD_INCLUDE_PATH
-#include <openvas/openvas_server.h>
-#else
 #include <openvas/misc/openvas_server.h>
-#endif
 
 /* Communication. */
 
